@@ -1685,7 +1685,7 @@ PyTypeObject PyGObject_MetaType = {
     0,                                  /* tp_methods */
     0,					/* tp_members */
     0,					/* tp_getset */
-    &PyType_Type,			/* tp_base */
+    NULL,				/* tp_base */
     (PyObject *)0,			/* tp_dict */
     0,					/* tp_descr_get */
     0,					/* tp_descr_set */
